@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """upload_docs
 
 Implements a Distutils 'upload_docs' subcommand (upload documentation to
@@ -9,7 +8,6 @@ from base64 import standard_b64encode
 from distutils import log
 from distutils.errors import DistutilsOptionError
 import os
-import socket
 import zipfile
 import tempfile
 import shutil
@@ -19,6 +17,7 @@ import http.client
 import urllib.parse
 
 from .._importlib import metadata
+from ..warnings import SetuptoolsDeprecationWarning
 
 from .upload import upload
 
@@ -35,10 +34,12 @@ class upload_docs(upload):
     description = 'Upload documentation to sites other than PyPi such as devpi'
 
     user_options = [
-        ('repository=', 'r',
-         "url of repository [default: %s]" % upload.DEFAULT_REPOSITORY),
-        ('show-response', None,
-         'display full response text from server'),
+        (
+            'repository=',
+            'r',
+            "url of repository [default: %s]" % upload.DEFAULT_REPOSITORY,
+        ),
+        ('show-response', None, 'display full response text from server'),
         ('upload-dir=', None, 'directory to upload'),
     ]
     boolean_options = upload.boolean_options
@@ -57,6 +58,10 @@ class upload_docs(upload):
         self.target_dir = None
 
     def finalize_options(self):
+        log.warn(
+            "Upload_docs command is deprecated. Use Read the Docs "
+            "(https://readthedocs.org) instead."
+        )
         upload.finalize_options(self)
         if self.upload_dir is None:
             if self.has_sphinx():
@@ -68,8 +73,6 @@ class upload_docs(upload):
         else:
             self.ensure_dirname('upload_dir')
             self.target_dir = self.upload_dir
-        if 'pypi.python.org' in self.repository:
-            log.warn("Upload_docs command is deprecated for PyPi. Use RTD instead.")
         self.announce('Using upload directory %s' % self.target_dir)
 
     def create_zipfile(self, filename):
@@ -82,13 +85,23 @@ class upload_docs(upload):
                     raise DistutilsOptionError(tmpl % self.target_dir)
                 for name in files:
                     full = os.path.join(root, name)
-                    relative = root[len(self.target_dir):].lstrip(os.path.sep)
+                    relative = root[len(self.target_dir) :].lstrip(os.path.sep)
                     dest = os.path.join(relative, name)
                     zip_file.write(full, dest)
         finally:
             zip_file.close()
 
     def run(self):
+        SetuptoolsDeprecationWarning.emit(
+            "Deprecated command",
+            """
+            upload_docs is deprecated and will be removed in a future version.
+            Instead, use tools like devpi and Read the Docs; or lower level tools like
+            httpie and curl to interact directly with your hosting service API.
+            """,
+            due_date=(2023, 9, 26),  # warning introduced in 27 Jul 2022
+        )
+
         # Run sub commands
         for cmd_name in self.get_sub_commands():
             self.run_command(cmd_name)
@@ -130,7 +143,10 @@ class upload_docs(upload):
         boundary = '--------------GHSKFJDLGDS7543FJKLFHRE75642756743254'
         sep_boundary = b'\n--' + boundary.encode('ascii')
         end_boundary = sep_boundary + b'--'
-        end_items = end_boundary, b"\n",
+        end_items = (
+            end_boundary,
+            b"\n",
+        )
         builder = functools.partial(
             cls._build_part,
             sep_boundary=sep_boundary,
@@ -163,8 +179,9 @@ class upload_docs(upload):
         # build the Request
         # We can't use urllib2 since we need to send the Basic
         # auth right with the first request
-        schema, netloc, url, params, query, fragments = \
-            urllib.parse.urlparse(self.repository)
+        schema, netloc, url, params, query, fragments = urllib.parse.urlparse(
+            self.repository
+        )
         assert not params and not query and not fragments
         if schema == 'http':
             conn = http.client.HTTPConnection(netloc)
@@ -183,7 +200,7 @@ class upload_docs(upload):
             conn.putheader('Authorization', auth)
             conn.endheaders()
             conn.send(body)
-        except socket.error as e:
+        except OSError as e:
             self.announce(str(e), log.ERROR)
             return
 
