@@ -8,12 +8,13 @@ import pytest
 import sys
 
 
-@pytest.mark.skipif(sys.platform != "win32",
-                    reason="These tests are only for win32")
+@pytest.mark.skipif(sys.platform != "win32", reason="These tests are only for win32")
 class TestMSVC14:
     """Python 3.8 "distutils/tests/test_msvccompiler.py" backport"""
+
     def test_no_compiler(self):
         import setuptools.msvc as _msvccompiler
+
         # makes sure query_vcvarsall raises
         # a DistutilsPlatformError if the compiler
         # is not found
@@ -24,9 +25,11 @@ class TestMSVC14:
         old_find_vcvarsall = _msvccompiler._msvc14_find_vcvarsall
         _msvccompiler._msvc14_find_vcvarsall = _find_vcvarsall
         try:
-            pytest.raises(DistutilsPlatformError,
-                          _msvccompiler._msvc14_get_vc_env,
-                          'wont find this version')
+            pytest.raises(
+                DistutilsPlatformError,
+                _msvccompiler._msvc14_get_vc_env,
+                'wont find this version',
+            )
         finally:
             _msvccompiler._msvc14_find_vcvarsall = old_find_vcvarsall
 
@@ -54,9 +57,7 @@ class TestMSVC14:
         # This function cannot be mocked, so pass it if we find VS 2017
         # and mark it skipped if we do not.
         version, path = _msvccompiler._msvc14_find_vc2017()
-        if os.environ.get('APPVEYOR_BUILD_WORKER_IMAGE', '') in [
-            'Visual Studio 2017'
-        ]:
+        if os.environ.get('APPVEYOR_BUILD_WORKER_IMAGE', '') == 'Visual Studio 2017':
             assert version
         if version:
             assert version >= 15
@@ -71,7 +72,8 @@ class TestMSVC14:
         # and mark it skipped if we do not.
         version, path = _msvccompiler._msvc14_find_vc2015()
         if os.environ.get('APPVEYOR_BUILD_WORKER_IMAGE', '') in [
-            'Visual Studio 2015', 'Visual Studio 2017'
+            'Visual Studio 2015',
+            'Visual Studio 2017',
         ]:
             assert version
         if version:
